:py:mod:`visualiser_com`
========================

.. py:module:: visualiser_com


Module Contents
---------------

.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: Exec
   

   Properties of the generated Node


.. py:data:: BaseName
   :annotation: = Visualiser

   

.. py:data:: NodeAttributeNames
   :annotation: = ['Parameters', 'In', 'Out']

   

.. py:data:: NodeAttributeType
   :annotation: = ['Static', 'Input', 'Output']

   

.. py:data:: ParameterNames
   :annotation: = ['Visualisation', 'Type', 'Buffer']

   

.. py:data:: ParameterTypes
   :annotation: = ['bool', 'list', 'int']

   

.. py:data:: ParametersDefaultValues
   :annotation: = [False, ['Image', 'Value', 'Single Pane Plot', 'Multi Pane Plot'], 100]

   

.. py:data:: WorkerDefaultExecutable
   

   

.. py:data:: visualiser_com
   

   

